bioneuralnet.utils.data — BioNeuralNet 1.0.4 documentation

# bioneuralnet.utils.data

Functions

`correlation_summary`(df) | Compute summary statistics of the maximum pairwise correlation
`explore_data_stats`(omics_df[, name]) | Print key statistics for an omics DataFrame including variance, zero fraction,
`expression_summary`(df) | Compute summary statistics for the mean expression of features
`get_logger`(name) | Retrieves a global logger configured to write to 'bioneuralnet.log' at the project root.
`variance_summary`(df[, low_var_threshold]) | Compute summary statistics for column variances in the DataFrame
`zero_fraction_summary`(df[, high_zero_threshold]) | Compute summary statistics for the fraction of zeros in each column

bioneuralnet.utils.data.correlation_summary(df: DataFrame) → dict

  Compute summary statistics of the maximum pairwise correlation

bioneuralnet.utils.data.explore_data_stats(omics_df: DataFrame, name: str = 'Data') → None

  Print key statistics for an omics DataFrame including variance, zero fraction,

bioneuralnet.utils.data.expression_summary(df: DataFrame) → dict

  Compute summary statistics for the mean expression of features

bioneuralnet.utils.data.variance_summary(df: DataFrame, low_var_threshold: float = None) → dict

  Compute summary statistics for column variances in the DataFrame

bioneuralnet.utils.data.zero_fraction_summary(df: DataFrame, high_zero_threshold: float = None) → dict

  Compute summary statistics for the fraction of zeros in each column